@@ -8,52 +8,54 @@
 #define PCGRAND_LIBRARY 1
 #define MKLRAND_LIBRARY 0
 #ifdef R_RELEASE
-		#undef   R_INTERFACE
-		#undef   M_INTERFACE
-		#undef   P_INTERFACE
-		#define  R_INTERFACE 1
-		#define  M_INTERFACE 0
+        #undef   R_INTERFACE
+        #undef   M_INTERFACE
+        #undef   P_INTERFACE
+        #define  R_INTERFACE 1
+        #define  M_INTERFACE 0
         #define  P_INTERFACE 0
-		#undef   MYMAT_LIBRARY
-	    #undef   MKL_LIBRARY
-		#define MYMAT_LIBRARY 1
-	    #define MKL_LIBRARY   0
-	    #define PCGRAND_LIBRARY 1
+        #undef   MYMAT_LIBRARY
+        #undef   MKL_LIBRARY
+        #define MYMAT_LIBRARY 1
+        #define MKL_LIBRARY   0
+        #define PCGRAND_LIBRARY 1
         #define MKLRAND_LIBRARY 0
-#endif
-#ifdef P_RELEASE
-		#undef   R_INTERFACE
-		#undef   M_INTERFACE
-		#undef   P_INTERFACE
-		#define  R_INTERFACE 0
-		#define  M_INTERFACE 0
+#elif  defined(P_RELEASE)
+        #undef   R_INTERFACE
+        #undef   M_INTERFACE
+        #undef   P_INTERFACE
+        #define  R_INTERFACE 0
+        #define  M_INTERFACE 0
         #define  P_INTERFACE 1
-		#undef   MYMAT_LIBRARY
-	    #undef   MKL_LIBRARY
-		#define MYMAT_LIBRARY 1
-	    #define MKL_LIBRARY   0
-	    #define PCGRAND_LIBRARY 1
+        #undef   MYMAT_LIBRARY
+        #undef   MKL_LIBRARY
+        #define MYMAT_LIBRARY 1
+        #define MKL_LIBRARY   0
+        #define PCGRAND_LIBRARY 1
         #define MKLRAND_LIBRARY 0
-#endif
-#ifdef M_RELEASE
-		#undef   R_INTERFACE
-		#undef   M_INTERFACE
-		#undef   P_INTERFACE
-		#define  R_INTERFACE 0
-		#define  M_INTERFACE 1
+#elif defined(M_RELEASE)
+        #undef   R_INTERFACE
+        #undef   M_INTERFACE
+        #undef   P_INTERFACE
+        #define  R_INTERFACE 0
+        #define  M_INTERFACE 1
         #define  P_INTERFACE 0
-		#undef   MYMAT_LIBRARY
-	    #undef   MKL_LIBRARY
-		#define MYMAT_LIBRARY 1
-	    #define MKL_LIBRARY   0
-	    #define PCGRAND_LIBRARY 1
+        #undef   MYMAT_LIBRARY
+        #undef   MKL_LIBRARY
+        #define MYMAT_LIBRARY 1
+        #define MKL_LIBRARY   0
+        #define PCGRAND_LIBRARY 1
         #define MKLRAND_LIBRARY 0
         #ifndef MATLAB_MEX_FILE
-			#define MATLAB_MEX_FILE
+            #define MATLAB_MEX_FILE
         #endif
         #define MATLAB_DEFAULT_RELEASE  R2017b
 #endif
-#ifdef _MSC_VER
+#if MYMAT_LIBRARY==1
+		#define PCGRAND_LIBRARY 1
+		#define MKLRAND_LIBRARY 0
+#endif
+#ifdef   _MSC_VER
 	#define COMPILER_MSVC
 #elif defined(__clang__)
 	#define COMPILER_CLANG
@@ -79,18 +81,6 @@
 #if defined(sun) && defined(__sun) && defined(__SVR4) 
 	#define OS_SOLARIS
 #endif
-#if _WIN64||__amd64__||defined(__LP64__)||(defined(__x86_64__) &&    !defined(__ILP32__) )||defined(_M_X64)||defined(__ia64)||defined (_M_IA64)||defined(__aarch64__)||defined(__powerpc64__)
-	#define TARGET_64
-#else
-	#define TARGET_32
-#endif
-#if __GNUC__
-	#if __x86_64__||__ppc64__
-		#define TARGET_64
-	#else
-		#define TARGET_32
-	#endif
-#endif
 #if defined(__x86_64__)||defined(_M_X64)
 	#define  cpu_x86_64
 #elif defined(i386)||defined(__i386__)||defined(__i386)||defined(_M_IX86)
@@ -132,13 +122,29 @@
 #elif defined(__m68k__)
 	#define   cpu_M68K 
 #endif
-#if defined(TARGET_32) && defined (COMPILER_MSVC)
-	#define _CRT_SECURE_NO_WARNINGS
-	#pragma warning (disable: 4703) 
+#if _WIN64||__amd64__||defined(__LP64__)||(defined(__x86_64__) &&    !defined(__ILP32__) )||defined(_M_X64)||defined(__ia64)||defined (_M_IA64)||defined(__aarch64__)||defined(__powerpc64__)
+	#define TARGET_64
+#else
+	#define TARGET_32
 #endif
-#if MYMAT_LIBRARY==1
-		#define PCGRAND_LIBRARY 1
-		#define MKLRAND_LIBRARY 0
+#if __GNUC__
+	#if __x86_64__||__ppc64__
+		#define TARGET_64
+	#else
+		#define TARGET_32
+	#endif
+#endif
+#ifndef   _GNU_SOURCE 
+   #define  _GNU_SOURCE 
+#endif
+#include <stdint.h>
+#undef _FEATURES_H
+#if   INTPTR_MAX==INT32_MAX
+	#define TARGET_32
+#elif INTPTR_MAX==INT64_MAX
+	#define TARGET_64
+#else
+	#error "Environment not 32 or 64-bit."
 #endif
 #if defined(COMPILER_MSVC)
 		#define INLINE    __inline
@@ -153,27 +159,12 @@
 		#define _restrict __restrict__		
         #define UNUSED_DECORATOR  __attribute__((unused))
 #endif
-#if   defined(OS_LINUX) && ( defined(COMPILER_GCC)||defined(COMPILER_CLANG) )
-	#ifdef _GNU_SOURCE 
-		#include <features.h>
-		#ifndef __USE_GNU
-			#define __MUSL__ 
-		#endif
-	#else
-		#define _GNU_SOURCE
-		#include <features.h>
-		#ifndef __USE_GNU
-		#define __MUSL__ 
-		#endif
-		#undef _GNU_SOURCE 
-	#endif
-#endif
 #ifdef COMPILER_MSVC
-    # define ALIGN32_BEG __declspec(align(32))
+    # define ALIGN32_BEG    __declspec(align(32))
     # define ALIGN32_END 
 #else
     # define ALIGN32_BEG
-    # define ALIGN32_END __attribute__((aligned(32)))
+    # define ALIGN32_END   __attribute__((aligned(32)))
 #endif
 	#define DIAG_STR(s) #s
 	#define DIAG_JOINSTR(x,y) DIAG_STR(x ## y)
@@ -254,7 +245,7 @@
 	ENABLE_WARNING(unused-variable,unused-variable,NOT_USED)  \
 	ENABLE_WARNING(pragmas,pragmas,NOT_USED) \
 	ENABLE_WARNING(unknown-pragmas,unknown-pragmas,NOT_USED) 
-#elif defined(COMPILER_CLANG)||1
+#elif defined(COMPILER_CLANG)   
 	#define  DISABLE_MANY_WARNINGS  \
 	DISABLE_WARNING(unknown-pragmas,unknown-pragmas,NOT_USED)  \
 	DISABLE_WARNING(pragmas,pragmas,NOT_USED) \
@@ -309,26 +300,56 @@
 	#define  DISABLE_MANY_WARNINGS 
 	#define  ENABLE_MANY_WARNINGS 	
 #endif
-#ifdef _WIN32_WINNT
-#undef  _WIN32_WINNT
-#define _WIN32_WINNT 0x0601
-#endif
-#include <stdint.h>
-#if   INTPTR_MAX==INT32_MAX
-	#define TARGET_32
-#elif INTPTR_MAX==INT64_MAX
-	#define TARGET_64
-#else
-	#error "Environment not 32 or 64-bit."
-#endif
 #define  CHANGE_TO_AVX_GCC  \
           DIAG_DO_PRAGMA(GCC optimization_level 3) \
           DIAG_DO_PRAGMA(GCC optimize("O3,Ofast,inline,omit-frame-pointer,no-asynchronous-unwind-tables")) \
           DIAG_DO_PRAGMA(GCC target("sse,sse2,sse3,ssse3,sse4,popcnt,avx,avx2,fma,tune=haswell"))  
+#if  defined(OS_LINUX) && ( defined(COMPILER_GCC)||defined(COMPILER_CLANG) )
+	#ifdef _GNU_SOURCE 
+		#include <features.h>
+		#ifndef __USE_GNU
+			#define __MUSL__ 
+		#endif
+	#else
+		#define _GNU_SOURCE
+		#include <features.h>
+		#ifndef __USE_GNU
+		    #define __MUSL__ 
+		#endif
+		#undef _GNU_SOURCE 
+	#endif
+#endif
+#if defined(__linux__)
+  #ifndef _GNU_SOURCE
+    #define __TEMP_ENABLE_GNU_SOURCE
+    #define _GNU_SOURCE
+  #endif
+  #include <features.h>
+  #ifdef __TEMP_ENABLE_GNU_SOURCE
+    #undef _GNU_SOURCE
+    #undef __TEMP_ENABLE_GNU_SOURCE
+  #endif
+  #if !defined(__GLIBC__) && !defined(__UCLIBC__) && !defined(__BIONIC__) \
+      && !defined(__USE_GNU)
+    #define USING_MUSL 1
+  #else
+    #define USING_MUSL 0
+  #endif
+#else
+  #define USING_MUSL 0
+#endif
 #define _in_
-#define _inout_
 #define _out_
+#define _inout_
 #define mv(n,src,dest)	r_cblas_scopy( n,src,1L,dest,1L) 
 #define cp(n,src,dest)    memcpy(dest,src,sizeof(F32)*(size_t)(n))
 #define SCPY(n,src,dest)  memcpy(dest,src,sizeof(F32)*(size_t)(n))
 #define FILL0(dest,n)       memset(dest,0L,sizeof(F32)*(size_t)(n))
+#if defined (COMPILER_MSVC) && defined(TARGET_32) 
+	#define _CRT_SECURE_NO_WARNINGS
+	#pragma warning (disable: 4703) 
+#endif
+#ifdef _WIN32_WINNT
+	#undef  _WIN32_WINNT
+	#define _WIN32_WINNT 0x0601
+#endif
