@@ -1,17 +1,17 @@
 #include "abc_000_warning.h"
-#if  defined(CLANG_COMPILER) && !defined(ARM64_OS)  
+#if  defined(COMPILER_CLANG) && !defined(cpu_ARM64)  
     #pragma clang optimize on
 	#pragma clang attribute push (__attribute__((target("avx,avx2,avx512f,avx512dq,avx512bw"))),apply_to=function)
 #endif
-#if  defined(GCC_COMPILER) && !defined(ARM64_OS)  
+#if  defined(COMPILER_GCC) && !defined(cpu_ARM64)  
     #pragma optimization_level 3
     #pragma GCC optimize("O3,Ofast,inline,omit-frame-pointer,no-asynchronous-unwind-tables")  
 	 #pragma GCC target("avx,avx2,avx512f,avx512dq,avx512bw") 
 #endif
-#if !defined(SOLARIS_COMPILER) && defined(TARGET_64) && !defined(ARM64_OS)
+#if !defined(COMPILER_SOLARIS) && defined(TARGET_64) && !defined(cpu_ARM64)
 #include <immintrin.h>
 #include "abc_vec.h"
-#ifdef MSVC_COMPILER
+#ifdef COMPILER_MSVC
     # define ALIGN64_BEG __declspec(align(64))
     # define ALIGN64_END 
 #else
@@ -353,7 +353,7 @@ v16sf pow512_ps(v16sf x,float n) {
     }
 }
 #endif 
-#if defined(CLANG_COMPILER) && !defined(ARM64_OS)
+#if defined(COMPILER_CLANG) && !defined(cpu_ARM64)
     #pragma clang attribute pop
 #endif
 #include "abc_000_warning.h"
