@@ -1,6 +1,5 @@
 #pragma once
 #include "abc_datatype.h"
-typedef enum  MOVETYPE { BIRTH,DEATH,MERGE,MOVE,ChORDER,NoChangeFixGlobal } MOVETYPE;
 #include "abc_mem.h"
 typedef struct _CRED_INTERVAL {
 	F32PTR CI95;
@@ -29,9 +28,9 @@ void ConstructCIStruct(
 	U08PTR _inout_  fastCIComputation,CI_PARAM* _out_ ciInfo,CI_RESULT* _out_ CI);
 extern void InsertNewRowToUpdateCI(CI_PARAM* _restrict info,CI_RESULT* _restrict ci);
 #define  RANDINTEGER(x0,x1,SEED)             ((x0)+(SEED)%( (x1)- (x0)+1))
-#define  RANDINT(x0,x1,SEED)                 (x0)==(x1) ? x1  :  ((x0)+(SEED)%( x1 -(x0)+1)) 
 #define  RANDI08(a,b)						 RANDINTEGER(a,b,*rnd08++)
 #define  RANDI16(a,b)					  	 RANDINTEGER(a,b,*rnd16++)
 #define  RANDI32(a,b)						 RANDINTEGER(a,b,*rnd32++)
-#define  RANDI_Skip_MIDNUM(rndInt,L,M,U)  rndInt=( rndInt=RANDI32(L,U-1),rndInt<(M)? rndInt:(rndInt+1) )
+#define  RANDINT(x0,x1,SEED)                ( x0==x1 ? x1 : x0+(I32) ( (U32)(SEED)%(U32) ((x1)-(x0)+1) ) )
+#define  RANDI_Skip_MIDNUM(rndInt,L,M,U)  out=( out=RANDI32(L,U-1),out<(M)? out:(out+1) )
 #define  RANDINT_SKIPONE(out,L,M,U,SEED)     out=( out=RANDINT(L,U-1,SEED),out<(M)? out:(out+1) )
